@@ -11,6 +11,16 @@ export default {
     const raw = fs.readFileSync("./settings.toml", "utf-8");
     const doc = toml.parse(raw);
 
+    function getParseEnv(parseEnv) {
+      if (parseEnv === "list_by_comma") {
+        return "comma";
+      }
+      if (parseEnv === "list_by_colon") {
+        return "colon";
+      }
+      return undefined;
+    }
+
     function buildElement(key, props) {
       let type = props.type;
       type = type.replaceAll("PathBuf", "String");
@@ -42,6 +52,7 @@ export default {
         deprecated: props.deprecated,
         enum: props.enum,
         env: props.env,
+        parseEnv: getParseEnv(props.parse_env),
         optional: !props.default_docs && props.optional,
         type,
       };
