@@ -1,4 +1,4 @@
-use crate::cli::args::{ENV_ARG, PROFILE_ARG};
+use crate::cli::args::{ToolArg, ENV_ARG, PROFILE_ARG};
 use crate::env_diff::{EnvDiff, EnvDiffOperation, EnvDiffPatches, EnvMap};
 use crate::file::replace_path;
 use crate::shell::ShellType;
@@ -14,6 +14,7 @@ use std::sync::RwLock;
 use std::{path, process};
 
 pub static ARGS: RwLock<Vec<String>> = RwLock::new(vec![]);
+pub static TOOL_ARGS: RwLock<Vec<ToolArg>> = RwLock::new(vec![]);
 #[cfg(unix)]
 pub static SHELL: Lazy<String> = Lazy::new(|| var("SHELL").unwrap_or_else(|_| "sh".into()));
 #[cfg(windows)]
@@ -150,9 +151,6 @@ pub static MISE_BIN_NAME: Lazy<&str> = Lazy::new(|| filename(&ARGV0));
 pub static MISE_LOG_FILE: Lazy<Option<PathBuf>> = Lazy::new(|| var_path("MISE_LOG_FILE"));
 pub static MISE_LOG_FILE_LEVEL: Lazy<Option<LevelFilter>> = Lazy::new(log_file_level);
 
-pub static HTTP_PROXY: Lazy<Option<String>> =
-    Lazy::new(|| var("https_proxy").or_else(|_| var("http_proxy")).ok());
-
 pub static __USAGE: Lazy<Option<String>> = Lazy::new(|| var("__USAGE").ok());
 
 // true if running inside a shim
